@@ -32,7 +32,10 @@ class DecayChain(object):
 		Production rate for each isotope in the decay chain as a function of time.
 		If a Nx2 np.ndarray, element n gives the production rate R_n up until
 		time t_n for the parent isotope. E.g. If the production rate of the parent
-		is 2 for 1 hour, and 1 for 3 hours, the array will be [[2, 1], [1, 3]].  
+		is 5 for 1 hour, and 8 for 3 hours, the array will be [[5, 1], [8, 4]].  If
+		instead time intervals are preferred to a monotonically increasing grid
+		of timestamps, set 'timestamp=False'.  In this case the production rate array
+		will be [[5, 1], [8, 3]]. (R=5 for 1 hour, R=8 for 3 hours).
 
 		If R is a dict, it specifies the production rate for multiple isotopes, 
 		where the keys are the isotopes and the values are type np.ndarray.
@@ -41,7 +44,8 @@ class DecayChain(object):
 		if R>0 for any isotopes other than the parent.  If R is a str, it must be a 
 		path to a file where the same data is provided.  Supported file types are
 		.csv, .json and .db files, where .json files must be in the 'records' format,
-		and .db files must have a table named 'R'.
+		and .db files must have a table named 'R'.  Also, each isotope must have
+		the same time grid, for both timestamp=True and timestamp=False.
 
 	A0 : float or dict
 		Initial activity.  If a float, the initial activity of the parent isotope.
@@ -52,6 +56,11 @@ class DecayChain(object):
 		Units of time for the chain. Options are 'ns', 'us', 'ms', 's', 'm', 'h', 
 		'd', 'y', 'ky', 'My', 'Gy'.  Default is 's'.
 
+	timestamp : bool, optional
+		Determines if the 'time' variable in R is to be read as a timestamp-like grid,
+		i.e. in monotonically increasing order, or as a series of time intervals.
+		Default is `True`.
+
 	Attributes
 	----------
 	R : pd.DataFrame
@@ -88,7 +97,7 @@ class DecayChain(object):
 
 	"""
 
-	def __init__(self, parent_isotope, R=None, A0=None, units='s'):
+	def __init__(self, parent_isotope, R=None, A0=None, units='s', timestamp=True):
 		if units.lower() in ['hr','min','yr','sec']:
 			units = {'hr':'h','min':'m','yr':'y','sec':'s'}[units.lower()]
 		self.units = units
@@ -157,6 +166,10 @@ class DecayChain(object):
 
 			self.R['isotope'] = [self._filter_name(i) for i in self.R['isotope']]
 
+			if not timestamp:
+				for ip in pd.unique(self.R['isotope']):
+					self.R.loc[self.R['isotope']==ip,'time'] = np.cumsum(self.R.loc[self.R['isotope']==ip,'time'])
+
 			time = np.insert(np.unique(self.R['time']), 0, [0.0])
 			for n,dt in enumerate(time[1:]-time[:-1]):
 				_R_dict = {p:self.R[self.R['isotope']==p].iloc[n]['R'] for p in pd.unique(self.R['isotope'])}
@@ -282,15 +295,22 @@ class DecayChain(object):
 		time = np.asarray(time)
 		A = np.zeros(len(time)) if time.shape else np.array(0.0)
 
+		finished = []
 		for m,(BR, chain) in enumerate(zip(*self._get_branches(isotope))):
 			lm = self._r_lm(units)*self._chain[chain, 0]
 			L = len(chain)
 			for i in range(L):
-				if i==L-1 and m>0:
+				sub = ''.join(map(str, chain[i:]))
+				if sub in finished:
 					continue
+				finished.append(sub)
+				# if i==L-1 and m>0: # only add A0 of end isotope once
+					# continue
 
 				ip = self.isotopes[chain[i]]
 				A0 = self.A0[ip] if _A_dict is None else _A_dict[ip]
+				if A0==0.0 and _R_dict is None:
+					continue
 				A_i = lm[-1]*(A0/lm[i])
 				
 				B_i = np.prod(lm[i:-1]*BR[i:-1])
@@ -559,8 +579,12 @@ class DecayChain(object):
 		Y = self.counts['counts'].to_numpy()
 		dY = self.counts['unc_counts'].to_numpy()
 
+		
+		wh = np.array([np.all(x>0) for x in X.T])
+		p0 = np.average(Y[wh]/X[:,wh], axis=1)
+		p0 = np.where((p0>0)&(np.isfinite(p0)), p0, 1.0)
+
 		func = lambda X_f, *R_f: np.dot(np.asarray(R_f), X_f)
-		p0 = np.ones(len(X))
 		fit, cov = curve_fit(func, X, Y, sigma=dY, p0=p0, bounds=(0.0*p0, np.inf*p0))
 
 		for n,ip in enumerate(R_isotopes):
@@ -700,7 +724,7 @@ class DecayChain(object):
 			max_plot = len(self.isotopes)
 
 		ordr = int(np.floor(np.log10(np.average(self.activity(self.isotopes[0], time)))/3.0))
-		lb_or = {-4:'p',-3:'n',-2:r'$\mu$',-1:'m',0:'',1:'k',2:'M',3:'G',4:'T'}[ordr]
+		lb_or = {-5:'f',-4:'p',-3:'n',-2:r'$\mu$',-1:'m',0:'',1:'k',2:'M',3:'G',4:'T',5:'E'}[ordr]
 		mult = 10**(-3*ordr)
 
 		if self.R is not None:
